import requests as requests

url = "https://fundor333.com/index.json"


class ManagerFeed:
    def __init__(self, feed_url: str):
        self._feed = requests.get(feed_url).json()
        self._item_feed = []
        self._feed_sections = []

    @property
    def item_feed(self):
        self._item_feed = self._feed["items"]
        return self._item_feed

    @property
    def feed_sections(self) -> set:
        self._feed_sections = set().union(*(d.keys() for d in self.item_feed))
        return self._feed_sections

    def elaborate_feed(self) -> dict:
        out = {}
        for e in self.item_feed:
            dict_you_want = {
                your_key: e.get(your_key, None)
                for your_key in self.feed_sections
            }
            out[dict_you_want["id"]] = dict_you_want
        return out

    def get_to_publish(
        self,
        list_done: list,
    ) -> (list, str):
        full_list = self.elaborate_feed()
        out = []
        other = ""
        for e in full_list.keys():
            if e not in list_done:
                out.append(full_list.get(e))
                other += f"\n{e}"
        return out, other.strip()



from configparser import ConfigParser

from jsonfeed2social.jsonfeed import ManagerFeed
from jsonfeed2social.social.mastodon import mastodon_sender
from jsonfeed2social.social.twitter import twitter_sender


def sender(config: ConfigParser, populatecache: bool):
    feed = ManagerFeed(config["feed"]["uri"])
    try:
        with open(config["cache"]["cachefile"]) as file:
            raw_lines = file.readlines()
    except FileNotFoundError:
        raw_lines = []
    lines = []
    for e in raw_lines:
        lines.append(e.strip())
    news, id_list = feed.get_to_publish(lines)
    print(id_list)
    if len(news) > 0:
        with open(config["cache"]["cachefile"], "a+") as file:
            file.write(id_list)
        if not populatecache:
            # We can send the message
            try:
                config["feed"]["tweet"]
                twitter_sender(config, news)
            except KeyError:
                pass
            try:
                config["feed"]["toot"]
                mastodon_sender(config, news)
            except KeyError:
                pass



from configparser import ConfigParser

import requests

from jsonfeed2social.exception import MastodonException
from jsonfeed2social.utility import get_message


def send_toot(tweet: str, host_instance: str, token: str):
    headers = {}
    headers["Authorization"] = "Bearer " + token
    data = {}
    data["status"] = tweet
    data["visibility"] = "public"

    response = requests.post(
        url=host_instance + "/api/v1/statuses", data=data, headers=headers
    )
    if response.status_code == 200:
        return True
    else:
        raise MastodonException(
            f"Status return {response.status_code} - {response.json()}"
        )


def mastodon_sender(config: ConfigParser, news: list):
    for e in news:
        send_toot(
            get_message(e, config["feed"]["toot"]),
            config["mastodon"]["instance_url"],
            config["mastodon"]["mastodon_access_token"],
        )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['jsonfeed2social', 'jsonfeed2social.social']

package_data = \
{'': ['*']}

install_requires = \
['Jinja2>=3.1.2,<4.0.0',
 'click>=8.1.3,<9.0.0',
 'configparser>=5.2.0,<6.0.0',
 'requests>=2.28.0,<3.0.0',
 'tweepy>=4.10.0,<5.0.0']

entry_points = \
{'console_scripts': ['jsonfeed2social = jsonfeed2social.__main__:launcher']}

setup_kwargs = {
    'name': 'jsonfeed2social',
    'version': '1.2.1',
    'description': 'Tweet and toot from your jsonfeeed',
    'long_description': '# Jsonfeed2social\n',
    'author': 'Fundor333',
    'author_email': 'fundor333@fundor333.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/fundor333/jsonfeed2social',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
